@@ -23,7 +23,6 @@ class MergeGroupsCommand : public Command {
 	
 public:
 	MergeGroupsCommand(string);
-	MergeGroupsCommand();
 	~MergeGroupsCommand() {}
 	
 	vector<string> setParameters();
@@ -44,7 +43,7 @@ private:
 	
 	bool abort, allLines, pickedGroups;
 	set<string> labels; //holds labels to be used
-	string groups, label, outputDir, inputDir, designfile, sharedfile, groupfile, countfile, method, fastafile;
+	string groups, label,  inputDir, designfile, sharedfile, groupfile, countfile, method, fastafile;
 	vector<string> Groups, outputNames;
 		
 	int process(SharedRAbundVectors*&, ofstream&, bool&);
