@@ -30,6 +30,12 @@ vector<string> PairwiseSeqsCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["phylip"] = tempOutNames;
+        outputTypes["column"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -86,84 +92,19 @@ string PairwiseSeqsCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-PairwiseSeqsCommand::PairwiseSeqsCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["phylip"] = tempOutNames;
-		outputTypes["column"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "PairwiseSeqsCommand", "PairwiseSeqsCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 PairwiseSeqsCommand::PairwiseSeqsCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-	
-		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters(); 
 			
-			ValidParameters validParameter("pairwise.seqs");
-			map<string, string>::iterator it;
+			ValidParameters validParameter;
 			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
 			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["phylip"] = tempOutNames;
-			outputTypes["column"] = tempOutNames;
-			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
-			
-
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			
-			if (inputDir == "not found"){	inputDir = "";		}
-            else {
-                map<string, string>::iterator it2;
-                string path;
-                it2 = parameters.find("fasta");
-                //user has given a template file
-                if(it2 != parameters.end()){
-                    path = util.hasPath(it2->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["fasta"] = inputDir + it2->second;		}
-                }
-                
-                it2 = parameters.find("oldfasta");
-                //user has given a template file
-                if(it2 != parameters.end()){
-                    path = util.hasPath(it2->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["oldfasta"] = inputDir + it2->second;		}
-                }
-                
-                it2 = parameters.find("column");
-                //user has given a template file
-                if(it2 != parameters.end()){
-                    path = util.hasPath(it2->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["column"] = inputDir + it2->second;		}
-                }
-            }
-
-            
 			fastaFileName = validParameter.validFile(parameters, "fasta");
 			if (fastaFileName == "not found") {
 				fastaFileName = current->getFastaFile();
@@ -213,12 +154,23 @@ PairwiseSeqsCommand::PairwiseSeqsCommand(string option)  {
 			
 			align = validParameter.valid(parameters, "align");		if (align == "not found"){	align = "needleman";	}
             
+            if (align == "blast") {
+                string blastlocation = "";
+                vector<string> locations = current->getLocations();
+                string path = current->getProgramPath();
+                bool foundTool = util.findBlastLocation(blastlocation, path, locations);
+
+                if (!foundTool){
+                    m->mothurOut("[WARNING]: Unable to locate blast executables, cannot use blast as align method. Using needleman instead.\n"); align = "needleman";
+                }
+            }
+            
             temp = validParameter.valid(parameters, "fitcalc");	if(temp == "not found"){	temp = "F";	}
             fitCalc = util.isTrue(temp);
 			
 			output = validParameter.valid(parameters, "output");		if(output == "not found"){	output = "column"; }
             if (output=="phylip") { output = "lt"; }
-			if ((output != "column") && (output != "lt") && (output != "square")) { m->mothurOut(output + " is not a valid output form. Options are column, lt and square. I will use column."); m->mothurOutEndLine(); output = "column"; }
+			if ((output != "column") && (output != "lt") && (output != "square")) { m->mothurOut(output + " is not a valid output form. Options are column, lt and square. I will use column.\n");  output = "column"; }
 			
 			calc = validParameter.valid(parameters, "calc");			
 			if (calc == "not found") { calc = "onegap";  }
@@ -246,7 +198,7 @@ int PairwiseSeqsCommand::execute(){
 		longestBase = 2000; //will need to update this in driver if we find sequences with more bases.  hardcoded so we don't have the pre-read user fasta file.
         numDistsBelowCutoff = 0;
 
-        if (outputDir == "") {  outputDir += util.hasPath(fastaFileName); }
+        if (outputdir == "") {  outputdir += util.hasPath(fastaFileName); }
         
         ifstream inFASTA;
         util.openInputFile(fastaFileName, inFASTA);
@@ -263,8 +215,8 @@ int PairwiseSeqsCommand::execute(){
         string outputFile = "";
         
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastaFileName));
-        if ((oldfastafile != "") && (column != ""))  {  variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(oldfastafile));  }
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastaFileName));
+        if ((oldfastafile != "") && (column != ""))  {  variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(oldfastafile));  }
         
         if (output == "lt") { //does the user want lower triangle phylip formatted file
             variables["[outputtag]"] = "phylip";
@@ -408,15 +360,15 @@ int driverColumn(pairwiseData* params){
         DistCalc* distCalculator;
         if (params->countends) {
             if (validCalculator.isValidCalculator("distance", params->distcalcType) ) {
-                if (params->distcalcType == "nogaps")			{	distCalculator = new ignoreGaps();	}
-                else if (params->distcalcType == "eachgap")	{	distCalculator = new eachGapDist();	}
-                else if (params->distcalcType == "onegap")		{	distCalculator = new oneGapDist();	}
+                if (params->distcalcType == "nogaps")			{	distCalculator = new ignoreGaps(params->cutoff);	}
+                else if (params->distcalcType == "eachgap")	{	distCalculator = new eachGapDist(params->cutoff);	}
+                else if (params->distcalcType == "onegap")		{	distCalculator = new oneGapDist(params->cutoff);	}
             }
         }else {
             if (validCalculator.isValidCalculator("distance", params->distcalcType) ) {
-                if (params->distcalcType == "nogaps")		{	distCalculator = new ignoreGaps();					}
-                else if (params->distcalcType == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-                else if (params->distcalcType == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
+                if (params->distcalcType == "nogaps")		{	distCalculator = new ignoreGaps(params->cutoff);					}
+                else if (params->distcalcType == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist(params->cutoff);	}
+                else if (params->distcalcType == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist(params->cutoff);		}
             }
         }
         
@@ -476,15 +428,15 @@ int driverFitCalc(pairwiseData* params){
         DistCalc* distCalculator;
         if (params->countends) {
             if (validCalculator.isValidCalculator("distance", params->distcalcType) ) {
-                if (params->distcalcType == "nogaps")			{	distCalculator = new ignoreGaps();	}
-                else if (params->distcalcType == "eachgap")	{	distCalculator = new eachGapDist();	}
-                else if (params->distcalcType == "onegap")		{	distCalculator = new oneGapDist();	}
+                if (params->distcalcType == "nogaps")			{	distCalculator = new ignoreGaps(params->cutoff);	}
+                else if (params->distcalcType == "eachgap")	{	distCalculator = new eachGapDist(params->cutoff);	}
+                else if (params->distcalcType == "onegap")		{	distCalculator = new oneGapDist(params->cutoff);	}
             }
         }else {
             if (validCalculator.isValidCalculator("distance", params->distcalcType) ) {
-                if (params->distcalcType == "nogaps")		{	distCalculator = new ignoreGaps();					}
-                else if (params->distcalcType == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-                else if (params->distcalcType == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
+                if (params->distcalcType == "nogaps")		{	distCalculator = new ignoreGaps(params->cutoff);					}
+                else if (params->distcalcType == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist(params->cutoff);	}
+                else if (params->distcalcType == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist(params->cutoff);		}
             }
         }
         
@@ -544,17 +496,18 @@ int driverLt(pairwiseData* params){
         
         ValidCalculators validCalculator;
         DistCalc* distCalculator;
+        double cutoff = 1.0;
         if (params->countends) {
             if (validCalculator.isValidCalculator("distance", params->distcalcType) ) {
-                if (params->distcalcType == "nogaps")			{	distCalculator = new ignoreGaps();	}
-                else if (params->distcalcType == "eachgap")	{	distCalculator = new eachGapDist();	}
-                else if (params->distcalcType == "onegap")		{	distCalculator = new oneGapDist();	}
+                if (params->distcalcType == "nogaps")			{	distCalculator = new ignoreGaps(cutoff);	}
+                else if (params->distcalcType == "eachgap")	{	distCalculator = new eachGapDist(cutoff);	}
+                else if (params->distcalcType == "onegap")		{	distCalculator = new oneGapDist(cutoff);	}
             }
         }else {
             if (validCalculator.isValidCalculator("distance", params->distcalcType) ) {
-                if (params->distcalcType == "nogaps")		{	distCalculator = new ignoreGaps();					}
-                else if (params->distcalcType == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-                else if (params->distcalcType == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
+                if (params->distcalcType == "nogaps")		{	distCalculator = new ignoreGaps(cutoff);					}
+                else if (params->distcalcType == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist(cutoff);	}
+                else if (params->distcalcType == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist(cutoff);		}
             }
         }
         
@@ -631,17 +584,18 @@ int driverSquare(pairwiseData* params){
         
         ValidCalculators validCalculator;
         DistCalc* distCalculator;
+        double cutoff = 1.0;
         if (params->countends) {
             if (validCalculator.isValidCalculator("distance", params->distcalcType) ) {
-                if (params->distcalcType == "nogaps")			{	distCalculator = new ignoreGaps();	}
-                else if (params->distcalcType == "eachgap")	{	distCalculator = new eachGapDist();	}
-                else if (params->distcalcType == "onegap")		{	distCalculator = new oneGapDist();	}
+                if (params->distcalcType == "nogaps")			{	distCalculator = new ignoreGaps(cutoff);	}
+                else if (params->distcalcType == "eachgap")	{	distCalculator = new eachGapDist(cutoff);	}
+                else if (params->distcalcType == "onegap")		{	distCalculator = new oneGapDist(cutoff);	}
             }
         }else {
             if (validCalculator.isValidCalculator("distance", params->distcalcType) ) {
-                if (params->distcalcType == "nogaps")		{	distCalculator = new ignoreGaps();					}
-                else if (params->distcalcType == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-                else if (params->distcalcType == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
+                if (params->distcalcType == "nogaps")		{	distCalculator = new ignoreGaps(cutoff);					}
+                else if (params->distcalcType == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist(cutoff);	}
+                else if (params->distcalcType == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist(cutoff);		}
             }
         }
         
@@ -706,7 +660,7 @@ int driverSquare(pairwiseData* params){
 void PairwiseSeqsCommand::createProcesses(string filename) {
 	try {
         vector<linePair> lines;
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<pairwiseData*> data;
         long long numSeqs = alignDB.getNumSeqs();
         
@@ -763,13 +717,13 @@ void PairwiseSeqsCommand::createProcesses(string filename) {
             dataBundle->setVariables(align, Estimators[0], countends, output, alignDB, oldFastaDB, lines[i+1].start, lines[i+1].end, match, misMatch, gapOpen, gapExtend, longestBase, cutoff);
             data.push_back(dataBundle);
             
-            thread* thisThread = NULL;
+            std::thread* thisThread = NULL;
             if (output == "column")     {
-                if (fitCalc)    { thisThread = new thread(driverFitCalc, dataBundle);   }
-                else            {  thisThread = new thread(driverColumn, dataBundle);   }
+                if (fitCalc)    { thisThread = new std::thread(driverFitCalc, dataBundle);   }
+                else            {  thisThread = new std::thread(driverColumn, dataBundle);   }
             }
-            else if (output == "lt")    { thisThread = new thread(driverLt, dataBundle);            }
-            else                        { thisThread = new thread(driverSquare, dataBundle);        }
+            else if (output == "lt")    { thisThread = new std::thread(driverLt, dataBundle);            }
+            else                        { thisThread = new std::thread(driverSquare, dataBundle);        }
             workerThreads.push_back(thisThread);
         }
 
