@@ -24,7 +24,6 @@
 class TrimSeqsCommand : public Command {
 public:
 	TrimSeqsCommand(string);
-	TrimSeqsCommand();
 	~TrimSeqsCommand(){}
 	
 	vector<string> setParameters();
@@ -41,7 +40,7 @@ public:
 	
 private:    
 	bool abort, createGroup;
-	string fastaFile, oligoFile, qFileName, groupfile, nameFile, countfile, outputDir;
+	string fastaFile, oligoFile, qFileName, groupfile, nameFile, countfile;
 	
 	bool flip, allFiles, qtrim, keepforward, pairedOligos, reorient, logtransform;
 	int maxAmbig, maxHomoP, minLength, maxLength, processors, tdiffs, bdiffs, pdiffs, ldiffs, sdiffs, comboStarts;
@@ -58,7 +57,6 @@ private:
 	vector<linePair> lines;
 	vector<linePair> qLines;
 	
-    bool getOligos();
 	long long createProcessesCreateTrim(string, string, string, string, string, string, string, string, string, string);
     int processNamesCountFiles(string trimFasta, set<string> badNames, map<string, string> groupMap, string trimNameFileName, string scrapNameFileName, string trimCountFileName, string scrapCountFileName, string groupFile);
 	int setLines(string, string);
